@@ -237,7 +237,7 @@ def _subtlex_uk(lexicon: citylex_pb2.Lexicon) -> None:
     counter = 0
     url = "http://crr.ugent.be/papers/SUBTLEX-UK.xlsx"
     logging.info("Requesting URL: %s", url)
-    with pandas.ExcelFile(url) as source:
+    with pandas.ExcelFile(url, engine="openpyxl") as source:
         sheet = source.sheet_names[0]
         # Disables parsing "nan" as, well, `nan`.
         df = source.parse(sheet, na_values=[], keep_default_na=False)
@@ -373,7 +373,7 @@ def _wikipron_uk(lexicon: citylex_pb2.Lexicon) -> None:
     counter = 0
     url = (
         "https://raw.githubusercontent.com/kylebgorman/"
-        "wikipron/master/data/wikipron/tsv/eng_uk_phonemic.tsv"
+        "wikipron/master/data/tsv/eng_uk_phonemic_filtered.tsv"
     )
     for line in _request_url_resource(url):
         (wordform, pron, *_) = line.rstrip().split("\t")
@@ -392,7 +392,7 @@ def _wikipron_us(lexicon: citylex_pb2.Lexicon) -> None:
     counter = 0
     url = (
         "https://raw.githubusercontent.com/kylebgorman/"
-        "wikipron/master/data/wikipron/tsv/eng_us_phonemic.tsv"
+        "wikipron/master/data/tsv/eng_us_phonemic_filtered.tsv"
     )
     for line in _request_url_resource(url):
         (wordform, pron, *_) = line.rstrip().split("\t")
@@ -408,12 +408,12 @@ def main() -> None:
     parser = argparse.ArgumentParser(description="Creates a CityLex lexicon")
     # Output paths.
     parser.add_argument(
-        "--output_textproto_path",
+        "--output-textproto-path",
         default="citylex.textproto",
         help="output textproto path (default: %(default)s)",
     )
     parser.add_argument(
-        "--output_tsv_path",
+        "--output-tsv-path",
         default="citylex.tsv",
         help="output TSV path (default: %(default)s)",
     )
